aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBrad Fitzpatrick <bradfitz@golang.org>2016-02-02 17:34:48 +0000
committerBrad Fitzpatrick <bradfitz@golang.org>2016-02-02 19:07:08 +0000
commitbeceea733970b5267e61cd301507b78fc05d8d48 (patch)
treedeef617bd979608ead0ffbdb3193e150f850e0f0
parent2639498f9b5e43dfceb6aa7aafb31bc313216e24 (diff)
downloadgo-beceea733970b5267e61cd301507b78fc05d8d48.tar.gz
go-beceea733970b5267e61cd301507b78fc05d8d48.zip
runtime/pprof: mark dragonfly and solaris as bad at pprof
Updates #13841 Change-Id: I121bce054e2756c820c76444e51357f474b7f3d6 Reviewed-on: https://go-review.googlesource.com/19161 Reviewed-by: Russ Cox <rsc@golang.org>
-rw-r--r--src/runtime/pprof/pprof_test.go14
1 files changed, 8 insertions, 6 deletions
diff --git a/src/runtime/pprof/pprof_test.go b/src/runtime/pprof/pprof_test.go
index 621d21d327..ab6b1835c5 100644
--- a/src/runtime/pprof/pprof_test.go
+++ b/src/runtime/pprof/pprof_test.go
@@ -96,7 +96,7 @@ func parseProfile(t *testing.T, bytes []byte, f func(uintptr, []uintptr)) {
if l < 5+3 {
t.Logf("profile too short: %#x", val)
if badOS[runtime.GOOS] {
- t.Skipf("ignoring failure on %s; see golang.org/issue/6047", runtime.GOOS)
+ t.Skipf("ignoring failure on %s; see golang.org/issue/13841", runtime.GOOS)
return
}
t.FailNow()
@@ -171,7 +171,7 @@ func testCPUProfile(t *testing.T, need []string, f func(dur time.Duration)) {
}
if badOS[runtime.GOOS] {
- t.Skipf("ignoring failure on %s; see golang.org/issue/6047", runtime.GOOS)
+ t.Skipf("ignoring failure on %s; see golang.org/issue/13841", runtime.GOOS)
return
}
// Ignore the failure if the tests are running in a QEMU-based emulator,
@@ -420,11 +420,13 @@ func deepStack(depth int) int {
return deepStack(depth-1) + 1
}
// Operating systems that are expected to fail the tests. See issue 6047.
var badOS = map[string]bool{
- "darwin": true,
- "netbsd": true,
- "plan9": true,
+ "darwin": true,
+ "netbsd": true,
+ "plan9": true,
+ "dragonfly": true,
+ "solaris": true,
}
func TestBlockProfile(t *testing.T) {
@@ -420,11 +420,13 @@ func deepStack(depth int) int {
return deepStack(depth-1) + 1
}
-// Operating systems that are expected to fail the tests. See issue 6047.
+// Operating systems that are expected to fail the tests. See issue 13841.
var badOS = map[string]bool{